#!/usr/bin/perl -w
use Test;
BEGIN { plan tests => 2 }
BEGIN { unshift @INC, "../blib/lib" } 
use POWER::SSL;

use Socket;
use Fcntl;
use Errno qw( EINPROGRESS EAGAIN );
use Time::HiRes qw( time sleep );


my ($SOCK, $w, $msg, $content, $sslcontent);

{ local *SOCK; $SOCK = *SOCK }
select( (select($SOCK), $|=1)[0] );
socket($SOCK, AF_INET, SOCK_STREAM, getprotobyname('tcp')) or die "socket: $!";
fcntl($SOCK, F_SETFL, O_NONBLOCK) or die "fcntl: $!";
connect($SOCK, sockaddr_in(80, pack("C4", 127,0,0,1))) or
    ($! != EINPROGRESS and die "connect: $!");
do { vec($w="",fileno($SOCK),1)=1; } unless select(undef,$w,undef,0);
die "connect: $!" if $!=ord getsockopt($SOCK,SOL_SOCKET,SO_ERROR);
$msg = "GET / HTTP/1.0\nHost: localhost\n\n";
do {
    my $n = syswrite($SOCK, $msg);
    die "write: $!" if (($! and $! != EAGAIN) and not defined $n);
    $msg = substr($msg, $n) if defined $n;
} while length($msg);
$content = "";
do {
    my $n = sysread($SOCK, my $buf = "", 100000);
    die "read: $!" if (($! and $! != EAGAIN) and not defined $n);
    $content .= substr($buf,0,$n);
    last if $! == 0 and $n == 0;
} while $content !~ /\r?\n\r?\n/;
#warn "len=".length($content)."\n";
#print $content;
ok(length($content)==0, "", "http://localhost/");


{ local *SOCK; $SOCK = *SOCK }
select( (select($SOCK), $|=1)[0] );
socket($SOCK, AF_INET, SOCK_STREAM, getprotobyname('tcp')) or die "socket: $!";
fcntl($SOCK, F_SETFL, O_NONBLOCK) or die "fcntl: $!";
connect($SOCK, sockaddr_in(443, pack("C4", 127,0,0,1))) or
    ($! != EINPROGRESS and die "connect: $!");
do { vec($w="",fileno($SOCK),1)=1; } unless select(undef,$w,undef,0);
die "connect: $!" if $!=ord getsockopt($SOCK,SOL_SOCKET,SO_ERROR);
$SSL = POWER::SSL->new($SOCK);
$msg = "GET / HTTP/1.1\nHost: localhost\n\n";
do {
    my $n = $SSL->sslwrite($msg);
    die "write: $!" if (($! and $! != EAGAIN) and not defined $n);
    $msg = substr($msg, $n) if defined $n;
} while length($msg);
$sslcontent = "";
while ($sslcontent !~ /\r?\n\r?\n/) {
    my $n = $SSL->sslread(my $buf, 100000);
    die "read: $!" if (($! and $! != EAGAIN) and not defined $n);
    $sslcontent .= substr($buf,0,$n) if $n;
    last if $! == 0 and defined($n) and $n == 0;
} 
#warn "len=".length($sslcontent)."\n";
#print $sslcontent;
ok(length($sslcontent)==0, "", "https://localhost/");

